@@ -70,7 +70,7 @@ def strReplace(func:macal.FunctionDefinition, scope: macal.Scope, filename: str)
     var = scope.GetVariable("var").GetValue()
     frm = scope.GetVariable("frm")
     wth = scope.GetVariable("with")
-    result = var.getValue().replace(frm.GetValue(), wth.GetValue())
+    result = var.GetValue().replace(frm.GetValue(), wth.GetValue())
     scope.SetReturnValue(result)
 
 
@@ -87,8 +87,9 @@ def startsWith(func:macal.FunctionDefinition, scope: macal.Scope, filename: str)
 def removeNonAscii(func:macal.FunctionDefinition, scope: macal.Scope, filename: str) -> None:
     """Implementation of RemoveNonAscii function"""
     macal.ValidateFunctionArguments(func, scope, filename)   
-    txt = scope.GetVariable("text")    
-    result = unidecode(txt.GetValue())
+    txt = scope.GetVariable("text")
+    text = txt.GetValue()
+    result = unidecode(text)
     scope.SetReturnValue(result)
 
 
@@ -99,7 +100,7 @@ def replaceEx(func:macal.FunctionDefinition, scope: macal.Scope, filename: str)
     var  = scope.GetVariable("var")
     repl = scope.GetVariable("repl")
     by   = scope.GetVariable("by")
-    result = var.GetValue().getValue()
+    result = var.GetValue().GetValue()
     r = repl.GetValue()    
     b = by.GetValue()
     for ch in r:
