@@ -7,13 +7,13 @@ import macal
 
 def strRight(func:macal.FunctionDefinition, scope: macal.Scope, filename: str) -> None:
     """Implementation of right function"""
-    macal.validateFunctionArguments(func, scope, filename)
-    arg = scope.getVariable("arg")
-    argl = scope.getVariable("length")
-    value = arg.getValue()
-    length = argl.getValue()
+    macal.ValidateFunctionArguments(func, scope, filename)
+    arg = scope.GetVariable("arg")
+    argl = scope.GetVariable("length")
+    value = arg.GetValue()
+    length = argl.GetValue()
     endpos = len(value)
     start = endpos - length
     result = scope.RunFunction('mid', scope, arg=arg, start=start, length=length)
-    scope.setReturnValue(result, macal.VariableTypes.String)
+    scope.SetReturnValue(result)
     
\ No newline at end of file
