@@ -258,7 +258,7 @@ class Interpreter:
             raise exceptions.RuntimeError(f'Binary Expression TypeCheck: Right is not a value item. ({type(right)}) Left: {left}, Right: {right}', None, self.filename)
         if operator == '$+': return
         if left.Type != right.Type:
-            if operator == '==' and (right.Type == types.VariableTypes.Bool or right.Type == types.VariableTypes.Nil):
+            if (operator == '==' or operator == '!=') and (right.Type == types.VariableTypes.Bool or right.Type == types.VariableTypes.Nil or left.Type == types.VariableTypes.Nil or left.Type == types.VariableTypes.Bool):
                 return
             if ((left.Type != types.VariableTypes.Int and left.Type != types.VariableTypes.Float) 
                  or (right.Type != types.VariableTypes.Int and right.Type != types.VariableTypes.Float)):
